@@ -5,6 +5,7 @@ import logging
 import re
 import lxml.etree
 from cStringIO import StringIO
+from gzip import GzipFile
 
 from holmes.facters import Facter
 from holmes.utils import _
@@ -95,6 +96,12 @@ class SitemapFacter(Facter):
         if response.status_code > 399 or response.text is None or not response.text.strip():
             return
 
+        try:
+            gzipped = GzipFile(mode='r', fileobj=StringIO(response.text))
+            response.text = gzipped.read()
+        except IOError:
+            pass
+
         self.review.facts['total.sitemap.indexes']['value'] += 1
 
         size_sitemap = len(response.text) / 1024.0
