@@ -3,66 +3,67 @@
 
 
 from holmes.validators.base import Validator
+from holmes.utils import _
 
 
 class RobotsValidator(Validator):
 
-    SITEMAP_NOT_FOUND = 'You must specify the location of the Sitemap ' \
-                        'using a robots.txt file'
+    SITEMAP_NOT_FOUND = _('You must specify the location of the Sitemap '
+                          'using a robots.txt file')
 
-    DISALLOW_NOT_FOUND = 'Disallow directive indicates that robots should ' \
-                         'not access the specific directory, subdirectory ' \
-                         'or file. '
+    DISALLOW_NOT_FOUND = _('Disallow directive indicates that robots should '
+                           'not access the specific directory, subdirectory '
+                           'or file. ')
 
-    DISALLOW_ROOT_PATH = 'Crawlers may not index anything, because ' \
-                         'the root path (/) is disallowed.'
+    DISALLOW_ROOT_PATH = _('Crawlers may not index anything, because '
+                           'the root path (/) is disallowed.')
 
     @classmethod
     def get_violation_definitions(cls):
         return {
             'robots.not_found': {
-                'title': 'Robots file not found',
-                'description': lambda value: "The robots file at '%s' was not found." % value,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Robots file not found'),
+                'description': _("The robots file at '%s' was not found."),
+                'category': _('SEO'),
+                'generic_description': _(
                     'Validates the presence of robots file. A robots.txt file tells a search '
                     'engine what content they will index or not.'
                 )
             },
             'robots.empty': {
-                'title': 'Robots file was empty',
-                'description': lambda value: "The robots file at '%s' was empty." % value,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Robots file was empty'),
+                'description': _("The robots file at '%s' was empty."),
+                'category': _('SEO'),
+                'generic_description': _(
                     'Validates the content of a robots file. If empty, the search engines '
                     'will understand that has no robots file present.'
                 )
             },
             'robots.sitemap.not_found': {
-                'title': 'Sitemap in Robots not found',
-                'description': lambda value: cls.SITEMAP_NOT_FOUND,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Sitemap in Robots not found'),
+                'description': cls.SITEMAP_NOT_FOUND,
+                'category': _('SEO'),
+                'generic_description': _(
                     'Validates the presence of Sitemap in Robots.txt. '
                     'The Sitemap tells the robot how your website is '
                     'organized and witch way can be indexed.'
                 )
             },
             'robots.disallow.not_found': {
-                'title': 'Disallow in Robots not found',
-                'description': lambda value: cls.DISALLOW_NOT_FOUND,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Disallow in Robots not found'),
+                'description': cls.DISALLOW_NOT_FOUND,
+                'category': _('SEO'),
+                'generic_description': _(
                     'Validates the presence of Disallow in Robots.txt. '
                     'Disallow lists the files and directories to be '
                     'excluded from indexing'
                 )
             },
             'robots.disallow.root_path': {
-                'title': 'Disallow: / in Robots',
-                'description': lambda value: cls.DISALLOW_ROOT_PATH,
-                'category': 'SEO',
-                'generic_description': (
+                'title': _('Disallow: / in Robots'),
+                'description': cls.DISALLOW_ROOT_PATH,
+                'category': _('SEO'),
+                'generic_description': _(
                     'Validates if the root path of your site is in '
                     'Disallow directive of Robots.txt. If true, the '
                     'root of your site will not be indexed on search '
